@@ -66,7 +66,6 @@
 #'   \item{cea}{A list containing the output of the economic evaluation performed using the function \code{\link[BCEA]{bcea}}}
 #'   \item{type}{A character variable that indicate which type of structural value mechanism has been used to run the model, 
 #'   either \code{SCAR} or \code{SAR} (see details)}
-#'   \item{data_format}{A character variable that indicate which type of analysis was conducted, either using a \code{wide} or \code{longitudinal} dataset}
 #' }
 #' @seealso \code{\link[R2jags]{jags}}, \code{\link[BCEA]{bcea}}
 #' @keywords CEA JAGS missing data Hurdle Models 
@@ -130,14 +129,14 @@
 #' @export
 #'
 #' @examples
-#' # Quick example to run using subset of MenSS dataset
+#' # Quck example to run using subset of MenSS dataset
 #' MenSS.subset <- MenSS[50:100, ]
 #' 
 #' # Run the model using the hurdle function assuming a SCAR mechanism
 #' # Use only 100 iterations to run a quick check
 #' model.hurdle <- hurdle(data = MenSS.subset, model.eff = e ~ 1,model.cost = c ~ 1,
 #'    model.se = se ~ 1, model.sc = sc ~ 1, se = 1, sc = 0, dist_e = "norm", dist_c = "norm",
-#'    type = "SCAR", n.chains = 2, n.iter = 50,  ppc = FALSE)
+#'    type = "SCAR", n.chains = 2, n.iter = 100,  ppc = FALSE)
 #' 
 #' # Print the results of the JAGS model
 #' print(model.hurdle)
@@ -578,7 +577,7 @@ hurdle <- function(data, model.eff, model.cost, model.se = se ~ 1, model.sc = sc
     }
     if(ind_fixed == TRUE) {
       if("beta_f.prior" %in% names(list_check_vector)) { stop(stop_mes) } 
-      if("mu.b_f.prior" %in% names(list_check_vector) | "s.b_f.prior" %in% names(list_check_vector)) { stop(stop_mes) } 
+      if("b_f.prior" %in% names(list_check_vector)) { stop(stop_mes) } 
     }
     if(ind_fixed == FALSE & ind_random == TRUE) {
       if("mu.b_f.prior" %in% names(list_check_vector) | "s.b_f.prior" %in% names(list_check_vector)) { stop(stop_mes) } 
@@ -679,9 +678,8 @@ hurdle <- function(data, model.eff, model.cost, model.se = se ~ 1, model.sc = sc
     if(exists("Kmax", where = exArgs)) {Kmax = exArgs$Kmax } else {Kmax = 50000 }
     if(exists("wtp", where = exArgs)) {wtp = exArgs$wtp } else {wtp = NULL }
     if(exists("plot", where = exArgs)) {plot = exArgs$plot } else {plot = FALSE }
-    cea <- BCEA::bcea(e = model_output$mean_effects, c = model_output$mean_costs, ref = ref, interventions = interventions, Kmax = Kmax, k = wtp, plot = plot)
-    format <- "wide"
-    res <- list(data_set = data_set, model_output = model_output, cea = cea, type = type, data_format = format)
+    cea <- BCEA::bcea(e = model_output$mean_effects, c = model_output$mean_costs, ref = ref, interventions = interventions, Kmax = Kmax, wtp = wtp, plot = plot)
+    res <- list(data_set = data_set, model_output = model_output, cea = cea, type = type)
   class(res) <- "missingHE"
   return(res)
 }
\ No newline at end of file
