@@ -1,27 +1,26 @@
 #' Summary method for objects in the class \code{missingHE}
 #'
 #' Produces a table printout with some summary results of the health economic evaluation probabilistic model
-#' run using the function \code{\link{selection}}, \code{\link{selection_long}}, \code{\link{pattern}} or \code{\link{hurdle}}.
+#' run using the function \code{\link{selection}}, \code{\link{pattern}} or \code{\link{hurdle}}.
 #' @param object A \code{missingHE} object containing the results of the Bayesian modelling and the economic evaluation
 #' @param ... Additional arguments affecting the summary produced.
 #' @return Prints a table with some information on the health economic model based on the assumption
-#' selected for the missingness using the function \code{selection}, \code{selection_long}, \code{pattern} or \code{hurdle}. 
+#' selected for the missingness using the function \code{selection}, \code{pattern} or \code{hurdle}. 
 #' Summary information on the main parameters of interests is provided.
-#' @seealso \code{\link{selection}}, \code{\link{selection_long}} \code{\link{pattern}} \code{\link{hurdle}} \code{\link{diagnostic}} \code{\link{plot.missingHE}}
+#' @seealso \code{\link{selection}} \code{\link{pattern}} \code{\link{hurdle}} \code{\link{diagnostic}} \code{\link{plot.missingHE}}
 #' @author Andrea Gabrio
 #' @references 
 #' Baio, G.(2012). \emph{Bayesian Methods in Health Economcis}. CRC/Chapman Hall, London.
 #' @importFrom stats quantile
 #' @export
 #' @examples 
-#' # For examples see the function \code{\link{selection}}, \code{\link{selection_long}},
-#' # \code{\link{pattern}} or \code{\link{hurdle}}
+#' #For examples see the function selection, pattern or hurdle
 #' #
 #' #
 
 summary.missingHE <- function(object, ...) {
   exArgs <- list(...)
-  if(!inherits(object, what = "missingHE")) {
+  if(!inherits(object, "missingHE")) {
     stop("Only objects of class 'missingHE' can be used")
   }
   mu_eff1 <- round(mean(object$cea$e[,1]), digits=3)
@@ -37,16 +36,16 @@ summary.missingHE <- function(object, ...) {
   sd_mu_cost2 <- round(sd(object$cea$c[,2]), digits = 3)
   sd_delta_e <- round(sd(unlist(object$cea$delta_e)), digits = 3)
   sd_delta_c <- round(sd(unlist(object$cea$delta_c)), digits = 3)
-  lower_mu_eff1 <- round(quantile(object$cea$e[,1], probs = 0.05), digits = 3)
-  lower_mu_eff2 <- round(quantile(object$cea$e[,2], probs = 0.05), digits = 3)
-  lower_mu_cost1 <- round(quantile(object$cea$c[,1], probs = 0.05), digits = 3)
-  lower_mu_cost2 <- round(quantile(object$cea$c[,2], probs = 0.05), digits = 3)
+  lower_mu_eff1 <- round(quantile(object$model_output$mean_effects[,1], probs = 0.05), digits = 3)
+  lower_mu_eff2 <- round(quantile(object$model_output$mean_effects[,2], probs = 0.05), digits = 3)
+  lower_mu_cost1 <- round(quantile(object$model_output$mean_costs[,1], probs = 0.05), digits = 3)
+  lower_mu_cost2 <- round(quantile(object$model_output$mean_costs[,2], probs = 0.05), digits = 3)
   lower_mu_delta_e <- round(quantile(unlist(object$cea$delta_e), probs = 0.05), digits = 3)
   lower_mu_delta_c <- round(quantile(unlist(object$cea$delta_c), probs = 0.05), digits = 3)
-  upper_mu_eff1 <- round(quantile(object$cea$e[,1], probs = 0.95), digits = 3)
-  upper_mu_eff2 <- round(quantile(object$cea$e[,2], probs = 0.95), digits = 3)
-  upper_mu_cost1 <- round(quantile(object$cea$c[,1], probs = 0.95), digits = 3)
-  upper_mu_cost2 <- round(quantile(object$cea$c[,2], probs = 0.95), digits = 3)
+  upper_mu_eff1 <- round(quantile(object$model_output$mean_effects[,1], probs = 0.95), digits = 3)
+  upper_mu_eff2 <- round(quantile(object$model_output$mean_effects[,2], probs = 0.95), digits = 3)
+  upper_mu_cost1 <- round(quantile(object$model_output$mean_costs[,1], probs = 0.95), digits = 3)
+  upper_mu_cost2 <- round(quantile(object$model_output$mean_costs[,2], probs = 0.95), digits = 3)
   upper_mu_delta_e <- round(quantile(unlist(object$cea$delta_e), probs = 0.95), digits = 3)
   upper_mu_delta_c <- round(quantile(unlist(object$cea$delta_c), probs = 0.95), digits = 3)
   rownames_v <- c("mean effects (t = 1)", "mean costs (t = 1)", "mean effects (t = 2)", "mean costs (t = 2)",
